# Edit Mesh

Edit mesh commands are used to edit an orphan mesh part or part instance or an Abaqus native mesh.

## Classes

### Edit mesh features of Assembly

```{eval-rst}
.. autoclass:: abaqus.EditMesh.MeshEditAssembly.MeshEditAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Edit mesh features of Part

```{eval-rst}
.. autoclass:: abaqus.EditMesh.MeshEditPart.MeshEditPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.EditMesh
        :recursive:
        :exclude: MeshEditAssembly, MeshEditPart
```
